Skip to contents

Add a template string to the library

Usage

add_template(library, template)

Arguments

library

Input must be a library dataframe created by initLibrary()

template

This should be one string template.

Value

A new library data frame containing the template that was added.

Examples

templates <- init_library()
templates <- add_template(templates, apple_template)