Skip to contents

Apple Output Template Example This is an example of an output template that reformats the statement as a CSV.

Usage

apple_csv

Format

apple_csv A string that contains Jinja syntax placeholders that match the apple_template.