Skip to contents

Apple Rosetta Statement Example This is an example of a statement that describes the weight of Apple X.

Usage

apple_statement

Format

apple_statement A string that specifies an object, a quality, a measurement and a unit.