R/add_template.R
add_template.Rd
Add a template string to the library
add_template(library, template)
Input must be a library dataframe created by initLibrary()
This should be one string template.
A new library data frame containing the template that was added.
templates <- init_library() templates <- add_template(templates, apple_template)