Apple Rosetta Statement Example This is an example of a statement that describes the weight of Apple X.
Source:R/data.R
apple_statement.RdApple Rosetta Statement Example This is an example of a statement that describes the weight of Apple X.